@@ -1,10 +1,10 @@
-import sys
+"""Models."""
 from astroid.nodes import Assign, Function, AssName
 from pylint.interfaces import IAstroidChecker
 from pylint.checkers.utils import check_messages
 from pylint.checkers import BaseChecker
 from pylint_django.__pkginfo__ import BASE_ID
-from pylint_django.utils import node_is_subclass
+from pylint_django.utils import node_is_subclass, PY3
 
 
 MESSAGES = {
@@ -17,11 +17,16 @@ MESSAGES = {
     'W%d02' % BASE_ID: ("Found __unicode__ method on model (%s). Python3 uses __str__.",
                         'model-has-unicode',
                         "Django models should not implement a __unicode__ "
-                        "method for string representation whan using Python3")
+                        "method for string representation when using Python3"),
+    'W%d03' % BASE_ID: ("Model does not explicitly define __unicode__ (%s)",
+                        'model-no-explicit-unicode',
+                        "Django models should implement a __unicode__ method for string representation. "
+                        "A parent class of this model does, but ideally all models should be explicit.")
 }
 
 
 class ModelChecker(BaseChecker):
+    """Django model checker."""
     __implements__ = IAstroidChecker
 
     name = 'django-model-checker'
@@ -29,6 +34,7 @@ class ModelChecker(BaseChecker):
 
     @check_messages('model-missing-unicode')
     def visit_class(self, node):
+        """Class visitor."""
         if not node_is_subclass(node, 'django.db.models.base.Model'):
             # we only care about models
             return
@@ -36,7 +42,7 @@ class ModelChecker(BaseChecker):
         for child in node.get_children():
             if isinstance(child, Assign):
                 grandchildren = list(child.get_children())
-  
+
                 if not isinstance(grandchildren[0], AssName):
                     continue
 
@@ -52,12 +58,27 @@ class ModelChecker(BaseChecker):
                 return
 
             if isinstance(child, Function) and child.name == '__unicode__':
-                if sys.version_info[0] >= 3:
+                if PY3:
                     self.add_message('W%s02' % BASE_ID, args=node.name, node=node)
                 return
 
-        # if we get here, then we have no __unicode__ method
-        if sys.version_info[0] >= 3:
+        # if we get here, then we have no __unicode__ method directly on the class itself
+        if PY3:
             return
 
+        # a different warning is emitted if a parent declares __unicode__
+        for method in node.methods():
+            if method.name == '__unicode__':
+                # this happens if a parent declares the unicode method but
+                # this node does not
+                self.add_message('W%s03' % BASE_ID, args=node.name, node=node)
+                return
+
+        # if the Django compatibility decorator is used then we don't emit a warning
+        # see https://github.com/landscapeio/pylint-django/issues/10
+        if node.decorators is not None:
+            for decorator in node.decorators.nodes:
+                if getattr(decorator, 'name', None) == 'python_2_unicode_compatible':
+                    return
+
         self.add_message('W%s01' % BASE_ID, args=node.name, node=node)
